==> nextcloud-app-bookmarks-1%3A14.2.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ast.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Detalles",
    "Rename" : "Renomar",
    "Copy link" : "Copiar l'enllaz",
    "Move" : "Mover",
    "Link copied to clipboard" : "L'enllaz copióse nel cartafueyu",
    "Delete selection" : "Desaniciar la seleición",
    "Select all" : "Seleicionar too",
    "Go back" : "Dir p'atrás",
    "New" : "Nuevu",
    "New folder" : "Carpeta nueva",
    "Search" : "Buscar",
    "Empty trash bin" : "Balerar la papelera",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n folders"],
    "Rename folder" : "Renomar la carpeta",
    "Submit" : "Unviar",
    "Cancel" : "Encaboxar",
    "Recent" : "De recién",
    "Shared with you" : "Compartióse contigo",
    "Files" : "Ficheros",
    "Delete" : "Desaniciar",
    "Settings" : "Configuración",
    "Bookmarklet" : "Bookmarklet",
    "Need help?" : "¿Precises ayuda?",
    "Title" : "Tñitulu",
    "Link" : "Enllaz",
    "Tags" : "Etiquetes",
    "Notes" : "Notes",
    "Owner" : "Propietariu",
    "Sharing" : "Comparticiñon",
    "Share link" : "Compartir l'enllaz",
    "Allow editing" : "Permitir la edición",
    "Link copied" : "Copióse l'enllaz",
    "Privacy" : "Privacidá",
    "Performance" : "Rindimientu",
    "Failed to save settings" : "Nun se pue guardar la configuración",
    "Failed to load settings" : "Nun se pue cargar la configuración",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL xá ta en Marcadores! ¿Quies sobrescribila?",
    "Folder" : "Carpeta",
    "Save" : "Guardar",
    "What's new?" : "Novedaes",
    "Failed to count unavailable bookmarks" : "Nun se puen contar los marcadores que nun tán disponibles",
    "Failed to count archived bookmarks" : "Nun se puen contar los marcadores archivaos",
    "Failed to count duplicated bookmarks" : "Nun se puen contar los marcadores duplicaos",
    "Failed to load bookmark" : "Nun se pue cargar el marcador",
    "Failed to find existing bookmark" : "Nun se pue atopar el marcadores esistente",
    "Failed to create bookmark" : "Nun se pue crear el marcador",
    "Failed to save bookmark" : "Nun se pue guardar el marcador",
    "Failed to move bookmark" : "Nun se pue mover el marcador",
    "Failed to copy bookmark" : "Nun se pue copiar el maracador",
    "Failed to delete bookmark" : "Nun se pue desaniciar el marcador",
    "Failed to rename tag" : "Nun se pue renomar la etiqueta",
    "Failed to load tags" : "Nun se puen cargar les etiquetes",
    "Failed to load folders" : "Nun se puen cargar les carpetes",
    "Failed to delete folder" : "Nun se pue desaniciar la carpeta",
    "Failed to create folder" : "Nun se pue desaniciar la carpeta",
    "Failed to fetch bookmarks." : "Nun se pue dir en cata de los marcadores.",
    "Failed to store setting" : "Nun se pue atroxar la configuración"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-bookmarks-1%3A15.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/ast.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Link copied to clipboard" : "L'enllaz copióse nel cartafueyu",
    "Details" : "Detalles",
    "Rename" : "Renomar",
    "Copy link" : "Copiar l'enllaz",
    "Move" : "Mover",
    "Delete selection" : "Desaniciar la seleición",
    "Select all" : "Seleicionar too",
    "Go back" : "Dir p'atrás",
    "New" : "Nuevu",
    "New folder" : "Carpeta nueva",
    "Search" : "Buscar",
    "Empty trash bin" : "Balerar la papelera",
    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetes"],
    "Rename folder" : "Renomar la carpeta",
    "Submit" : "Unviar",
    "Cancel" : "Encaboxar",
    "Recent" : "De recién",
    "Shared with you" : "Compartióse contigo",
    "Files" : "Ficheros",
    "Delete" : "Desaniciar",
    "Bookmarklet" : "Bookmarklet",
    "Need help?" : "¿Precises ayuda?",
    "Title" : "Tñitulu",
    "Link" : "Enllaz",
    "Tags" : "Etiquetes",
    "Notes" : "Notes",
    "Link copied" : "Copióse l'enllaz",
    "Owner" : "Propietariu",
    "Sharing" : "Comparticiñon",
    "Share link" : "Compartir l'enllaz",
    "Allow editing" : "Permitir la edición",
    "Failed to save settings" : "Nun se pue guardar la configuración",
    "Failed to load settings" : "Nun se pue cargar la configuración",
    "Privacy" : "Privacidá",
    "Performance" : "Rindimientu",
    "This URL is already bookmarked! Overwrite?" : "¡Esta URL xá ta en Marcadores! ¿Quies sobrescribila?",
    "Folder" : "Carpeta",
    "Save" : "Guardar",
    "What's new?" : "Novedaes",
    "Failed to count unavailable bookmarks" : "Nun se puen contar los marcadores que nun tán disponibles",
    "Failed to count archived bookmarks" : "Nun se puen contar los marcadores archivaos",
    "Failed to count duplicated bookmarks" : "Nun se puen contar los marcadores duplicaos",
    "Failed to load bookmark" : "Nun se pue cargar el marcador",
    "Failed to find existing bookmark" : "Nun se pue atopar el marcadores esistente",
    "Failed to create bookmark" : "Nun se pue crear el marcador",
    "Failed to save bookmark" : "Nun se pue guardar el marcador",
    "Failed to move bookmark" : "Nun se pue mover el marcador",
    "Failed to copy bookmark" : "Nun se pue copiar el maracador",
    "Failed to delete bookmark" : "Nun se pue desaniciar el marcador",
    "Failed to rename tag" : "Nun se pue renomar la etiqueta",
    "Failed to load tags" : "Nun se puen cargar les etiquetes",
    "Failed to load folders" : "Nun se puen cargar les carpetes",
    "Failed to delete folder" : "Nun se pue desaniciar la carpeta",
    "Failed to create folder" : "Nun se pue desaniciar la carpeta",
    "Failed to fetch bookmarks." : "Nun se pue dir en cata de los marcadores.",
    "Failed to store setting" : "Nun se pue atroxar la configuración"
},
"nplurals=2; plural=(n != 1);");
